@@ -86,26 +86,22 @@ int store(AddressRegion *pAddressRegion, char *data, int len)
 
 int unlockall(AddressRegion *pAddressRegion)
 {
-    int r;
+    int r = -1;
     if (pAddressRegion->processLocked)
     {
         r = munlockall(); /* unlock the process */
         if (!r && pAddressRegion->memLocked)
             mlock(pAddressRegion->pBytes, pAddressRegion->nBytes); /* relock it to memory */
         pAddressRegion->processLocked = 0;
-    } else {
-        r = -1;
     }
     return r;
 }
 
 int lockall(AddressRegion *pAddressRegion)
 {
-    int r;
-    if (pAddressRegion->processLocked)
+    int r = -1;
+    if (!pAddressRegion->processLocked)
     {
-        r = -1;
-    } else {
         r = mlockall(MCL_CURRENT | MCL_FUTURE); /* Lock everything now and future */
         if (!r)
             pAddressRegion->processLocked = 1; /* Record that it's locked if it succeeded */
